@@ -31,7 +31,6 @@
 #include "photos-gegl.h"
 #include "photos-pipeline.h"
 #include "photos-pixbuf.h"
-#include "photos-resources-gegl.h"
 #include "photos-thumbnailer.h"
 #include "photos-thumbnailer-dbus.h"
 
@@ -41,7 +40,6 @@ struct _PhotosThumbnailer
   GApplication parent_instance;
   GDBusConnection *connection;
   GHashTable *cancellables;
-  GResource *resource_gegl;
   PhotosThumbnailerDBus *skeleton;
   gchar *address;
 };
@@ -761,15 +759,9 @@ photos_thumbnailer_shutdown (GApplication *application)
 static void
 photos_thumbnailer_startup (GApplication *application)
 {
-  PhotosThumbnailer *self = PHOTOS_THUMBNAILER (application);
-
   G_APPLICATION_CLASS (photos_thumbnailer_parent_class)->startup (application);
 
   photos_gegl_init ();
-
-  self->resource_gegl = photos_gegl_get_resource ();
-  g_resources_register (self->resource_gegl);
-
   photos_debug (PHOTOS_DEBUG_THUMBNAILER, "Thumbnailer ready");
 }
 
@@ -783,7 +775,6 @@ photos_thumbnailer_dispose (GObject *object)
 
   g_clear_object (&self->connection);
   g_clear_pointer (&self->cancellables, g_hash_table_unref);
-  g_clear_pointer (&self->resource_gegl, g_resources_unregister);
 
   G_OBJECT_CLASS (photos_thumbnailer_parent_class)->dispose (object);
 }
